Package: uavRmp
Type: Package
Title: UAV Mission Planner
Version: 0.7
Date: 2024-06-07
Authors@R: c(person("Chris", "Reudenbach", email = "reudenbach@uni-marburg.de", role = c("cre", "aut")),
             person("Marvin", "Ludwig", role = c("ctb")),
             person("Sebastian", "Richter", role = c("ctb")),
             person("Florian", "Detsch", role = c("ctb")),
             person("Hanna", "Meyer", role = c("ctb"))
             )
Encoding: UTF-8
Maintainer: Chris Reudenbach <reudenbach@uni-marburg.de>
Description: The Unmanned Aerial Vehicle Mission Planner provides an easy to use work flow for planning autonomous obstacle avoiding surveys of ready to fly unmanned aerial vehicles to retrieve aerial or spot related data. It creates either intermediate flight control files for the DJI-Litchi supported series or ready to upload control files for the pixhawk-based flight controller. Additionally it contains some useful tools for digitizing and data manipulation.
URL: https://github.com/gisma/uavRmp
BugReports: https://github.com/gisma/uavRmp/issues
License: GPL (>= 3) | file LICENSE
Depends: R (>= 3.1.0)
Imports: sp, sf, geosphere, tools, log4r, zoo, methods, brew, exifr,
        link2GI, data.table, jsonlite, rlist, xfun, terra, concaveman,
        dplyr, spatialEco
RoxygenNote: 7.3.1
SystemRequirements: GNU make
Suggests: knitr, rmarkdown, markdown, mapview, grDevices, stringr,
        htmltools, htmlwidgets,
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2024-06-07 08:47:10 UTC; creu
Author: Chris Reudenbach [cre, aut],
  Marvin Ludwig [ctb],
  Sebastian Richter [ctb],
  Florian Detsch [ctb],
  Hanna Meyer [ctb]
Repository: CRAN
Date/Publication: 2024-06-07 09:10:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:30:04 UTC; unix
