# Generated by roxygen2: do not edit by hand

export(makeAP)
export(makeTP)
export(maxpos_on_line)
export(minBB)
export(soloLog)
export(solo_upload)
export(sp_line)
export(sp_point)
export(vecDraw)
import(dplyr)
import(log4r)
import(sf)
importFrom(geosphere,bearing)
importFrom(geosphere,destPoint)
importFrom(geosphere,distGeo)
importFrom(link2GI,linkGDAL)
importFrom(methods,as)
importFrom(rlist,list.cbind)
